@@ -47,7 +47,7 @@ case "$1" in
         set -e
 
         chown $WWW_USER "$VAR_DIR/$USER_DB"
-        chmod u=rw,g=r,o= "$VAR_DIR/$USER_DB"
+        chmod u=rw,g=rw,o= "$VAR_DIR/$USER_DB"
 
         if [ -e /usr/share/apache2/apache2-maintscript-helper ];then
             # Debian Jessie / Apache2.4
